@@ -17,7 +17,7 @@ set -e
 # for details, see http://www.debian.org/doc/debian-policy/ or
 # the debian-policy package
 
-IMAPUSER_TABLE=/usr/share/doc/benno-imap/imapuser.sql
+IMAPUSER_TABLE=/usr/share/benno-imap/imapuser.sql
 DATABASE_DIR=/var/lib/benno-web
 DATABASE_FILE="$DATABASE_DIR/bennoweb.sqlite"
 CONF_DIR=/etc/benno-imap
